pub mod base;

#[allow(dead_code, unused_imports)]
#[path = "./events_generated.rs"]
pub mod events_generated;
#[allow(dead_code, unused_imports)]
#[path = "./frame_generated.rs"]
pub mod frame_generated;
#[allow(dead_code, unused_imports)]
#[path = "./imus_generated.rs"]
pub mod imus_generated;
#[allow(dead_code, unused_imports)]
#[path = "./triggers_generated.rs"]
pub mod triggers_generated;
